diff --git a/src/THcAerogel.cxx b/src/THcAerogel.cxx
index d2a86ba14a4202c9cc980572e519ac411c1d9faa..a93e090537b138ce5fa6a33c18cd72b35a487147 100644
--- a/src/THcAerogel.cxx
+++ b/src/THcAerogel.cxx
@@ -1,10 +1,8 @@
 /** \class THcAerogel
     \ingroup Detectors
 
-    Class for an Aerogel detector consisting of pairs of PMT's
+\brief Class for an Aerogel detector consisting of pairs of PMT's
     attached to a diffuser box
-    Will have a fixed number of pairs, but need to later make this
-    configurable.
 */
 
 #include "THcAerogel.h"
diff --git a/src/THcAnalyzer.cxx b/src/THcAnalyzer.cxx
index 84da42f0a239149e6068ceb7a14d6abd1ddd40bb..e4101d6293ec9d1f7cb9b3ec3f605272946d26c1 100644
--- a/src/THcAnalyzer.cxx
+++ b/src/THcAnalyzer.cxx
@@ -1,20 +1,13 @@
 /** \class THcAnalyzer
     \ingroup Base
 
-THcAnalyzer is the base class for a "Hall C analyzer" class.
-An analyzer defines the basic actions to perform during analysis.
-THcAnalyzer is the default analyzer that is used if no user class is
-defined.  It performs a standard analysis consisting of
+\brief Hall C analyzer class.
 
-   1. Decoding/Calibrating
-   2. Track Reconstruction
-   3. Physics variable processing
+Adds the following to the Hall A analyzer base class.
 
-At the end of each step, testing and histogramming are done for
-the appropriate block defined in the global test/histogram lists.
+1.  PrintReport method to make text reports from template files
 
-Hall C ENGINE style reports are implemented with the PrintReport
-method.  This can be used for generating end of run summary sheets.
+2.  Retrieve run number and startind and ending event from parameter DB
 
 \author S. A. Wood,  13-March-2012
 
diff --git a/src/THcCherenkov.cxx b/src/THcCherenkov.cxx
index cd292eeecb13134305b2e50fc390177058dbf4da..de38d09012a311e7edc45d9d06b945319ea45bbb 100644
--- a/src/THcCherenkov.cxx
+++ b/src/THcCherenkov.cxx
@@ -1,7 +1,7 @@
 /** \class THcCherenkov
     \ingroup Detectors
 
-    Class for Cherenkov detectors
+\brief Class for gas Cherenkov detectors
 
 */
 
diff --git a/src/THcDC.cxx b/src/THcDC.cxx
index dc8003b479d3bc20ec4a789d74c2a2b115fca37e..071e2634b17426db467651561c5871fb49c298ba 100644
--- a/src/THcDC.cxx
+++ b/src/THcDC.cxx
@@ -1,6 +1,9 @@
 /** \class THcDC
     \ingroup Detectors
-This class analyzes a package of horizontal drift chambers.  It uses the
+
+\brief Analyze a package of horizontal drift chambers.
+
+Uses the
 first letter of the apparatus name as a prefix to parameter names.  The
 paramters, read in the Setup method, determine the number of chambers and
 the number of parameters per plane.
diff --git a/src/THcDetectorMap.cxx b/src/THcDetectorMap.cxx
index 8b3551c51b38f01cfb4d6deaa101b7f34ffa3c59..6a4a1b207536cc17cd50fe2bd73c6c8a3a70594e 100644
--- a/src/THcDetectorMap.cxx
+++ b/src/THcDetectorMap.cxx
@@ -1,10 +1,9 @@
 /** \class THcDetectorMap
     \ingroup Base
 
+\brief Class to read and hold a Hall C style detector map
 
-
- Class to read and Hall C style detector map
-   FillMap method builds a map for a specific detector
+FillMap method builds a map for a specific detector
 
 \author S. A. Wood
 
diff --git a/src/THcDummySpectrometer.cxx b/src/THcDummySpectrometer.cxx
index 937ef7e13d5b6ca67078a6f1888bfc7f9858c772..4f651be527f49318b2dcc689d992c3a0adb85738 100644
--- a/src/THcDummySpectrometer.cxx
+++ b/src/THcDummySpectrometer.cxx
@@ -2,7 +2,7 @@
 \class THcDummySpectrometer
 \ingroup Base
 
-\brief A dummy spectrometer used for testing detectors.
+\brief A dummy spectrometer apparatus for testing detectors.
 
 This class behaves as a spectrometer apparatus in that it holds detector
 classes, but it does no reconstruction. It is intended to provide an elegant
diff --git a/src/THcFormula.cxx b/src/THcFormula.cxx
index 83a844992c9d81396f86424fa7772f71f607608d..6e7cd33fe72010728bacaf72ef358ed925cfb298 100644
--- a/src/THcFormula.cxx
+++ b/src/THcFormula.cxx
@@ -1,7 +1,7 @@
 /** \class THcFormula
     \ingroup Base
 
-Enhanced THaFormula for use in report files.
+\brief Enhanced THaFormula for use in report files.
 
 In addition to global variables (gHaVars) and cuts (gHaCuts),
 THcFormula expressions have access hcana parameters (gHcParms).
diff --git a/src/THcHallCSpectrometer.cxx b/src/THcHallCSpectrometer.cxx
index 14d1eb1d24d40dbc5d688b891fd68330fd9e3a4f..b912ceba6bcbc362863e2b51a115635f623c34d3 100644
--- a/src/THcHallCSpectrometer.cxx
+++ b/src/THcHallCSpectrometer.cxx
@@ -1,13 +1,14 @@
 /** \class THcHallCSpectrometer
     \ingroup Base
 
- A standard Hall C spectrometer.
- Contains no standard detectors,
+\brief A standard Hall C spectrometer apparatus
 
- The usual name of this object is either "H", "S", "P"
- for HMS, SOS, or suPerHMS respectively
+ Uses the standard optics polynomials to trace back to target
 
+ Contains no standard detectors.  All detectors must be added.
 
+ The usual name of this object is either "H", "S", "P"
+ for HMS, SOS, or suPerHMS respectively
 
 \author S. A. Wood
 
diff --git a/src/THcHitList.cxx b/src/THcHitList.cxx
index 41f7815ad4b5136f63e89e28e6032afe5ae3f7ae..7f948f967c9da9f88a2ae93dc9656cad48f7b78f 100644
--- a/src/THcHitList.cxx
+++ b/src/THcHitList.cxx
@@ -1,7 +1,8 @@
 /** \class THcHitList
     \ingroup Base
 
- Class to build a Hall C ENGINE style list of raw hits from the raw data.
+\brief Builds a Hall C ENGINE style list of raw hits from raw data
+
  Detectors that use hit lists need to inherit from this class
  as well as THaTrackingDetector or THaNonTrackingDetector
 
@@ -18,7 +19,7 @@ using namespace std;
 
 THcHitList::THcHitList()
 {
-  // Normal constructor.
+  /// Normal constructor.
 
   fRawHitList = NULL;
   fPSE125 = NULL;
@@ -26,14 +27,23 @@ THcHitList::THcHitList()
 }
 
 THcHitList::~THcHitList() {
-  // Destructor
+  /// Destructor
   delete fSignalTypes;
 }
+/**
+
+\brief Save the electronics module to detector mapping and
+initialize a hit array of hits of class hitclass
+
+\param[in] detmap Electronics mapping made by THcDetectorMap::FillMap
+\param[in] hitclass Name of hit class used by this detector
+\param[in] maxhits Maximum number of hits for this detector
+
+*/
 
 void THcHitList::InitHitList(THaDetMap* detmap,
 				  const char *hitclass, Int_t maxhits) {
-  // Save the electronics to detector mapping
-  // Initialize a hit array of hits of class hitclass
+
 
   fRawHitList = new TClonesArray(hitclass, maxhits);
   fRawHitClass = fRawHitList->GetClass();
@@ -112,15 +122,18 @@ void THcHitList::InitHitList(THaDetMap* detmap,
   }
 }
 
-Int_t THcHitList::DecodeToHitList( const THaEvData& evdata ) {
-  // Clear the hit list
-  // Find all populated channels belonging to the detector and add
-  // the data to the hitlist.  A given counter in the detector can have
-  // at most one entry in the hit list.  However, the raw "hit" can contain
-  // multiple signal types (e.g. ADC+, ADC-, TDC+, TDC-), or multiple
-  // hits for multihit tdcs.
-  // The hit list is sorted (by plane, counter) after filling.
+/**
+
+\brief Populate the hitlist from the raw event data.
+
+Clears the hit list then, finds all populated channels belonging to the detector and add
+sort it into the hitlist.  A given counter in the detector can have
+at most one entry in the hit list.  However, the raw "hit" can contain
+multiple signal types (e.g. ADC+, ADC-, TDC+, TDC-), or multiplehits for multihit tdcs.
+The hit list is sorted (by plane, counter) after filling.
 
+*/
+Int_t THcHitList::DecodeToHitList( const THaEvData& evdata ) {
 
   // cout << " Clearing TClonesArray " << endl;
   fRawHitList->Clear( );
diff --git a/src/THcHodoEff.cxx b/src/THcHodoEff.cxx
index bcf662960403f3e164b1bc5e284b4a33db723464..c44da24b9f54c170ccc45151d8bec77a29df1bdf 100644
--- a/src/THcHodoEff.cxx
+++ b/src/THcHodoEff.cxx
@@ -1,8 +1,7 @@
 /** \class THcHodoEff
-    \ingroup DetSupport
+    \ingroup PhysMods
 
- Class for accumulating statistics for and calculating hodoscope
- efficiencies.
+\brief Class for accumulating statistics for and calculating hodoscope efficiencies.
 
 */
 #include "THaEvData.h"
diff --git a/src/THcHodoscope.cxx b/src/THcHodoscope.cxx
index 9d91c7fdb1af6f039d416407cc1ce284c52b5b7f..33c0d69e08e91863504c480adfbf68003842be00 100644
--- a/src/THcHodoscope.cxx
+++ b/src/THcHodoscope.cxx
@@ -1,8 +1,9 @@
 /** \class THcHodoscope
     \ingroup Detectors
 
-Class for a generic hodoscope consisting of multiple
+\brief Generic hodoscope consisting of multiple
 planes with multiple paddles with phototubes on both ends.
+
 This differs from Hall A scintillator class in that it is the whole
 hodoscope array, not just one plane.
 
diff --git a/src/THcInterface.cxx b/src/THcInterface.cxx
index dd75912c365517eaf28ec4eb96d9a927693ac804..230d57fdfb56576394d6fa024c67f884f43edf74 100644
--- a/src/THcInterface.cxx
+++ b/src/THcInterface.cxx
@@ -1,9 +1,10 @@
 /** \class THcInterface
     \ingroup Base
 
- THcInterface is the interactive interface to the Hall C Analyzer.
- It allows interactive access to all analyzer classes as well as
- all of standard ROOT.
+\brief THcInterface is the interactive interface to the Hall C Analyzer.
+
+Basically a rebranded copy of THaInterface with the addition of a global
+for the Hall C style parameter database.
 
 */
 
diff --git a/src/THcRasteredBeam.cxx b/src/THcRasteredBeam.cxx
index 41efe1f44b336f7e7abb633191978cdb1d8cbf23..8f15d8b813d2ab4fd42861f2e426820e4e8ca0bb 100644
--- a/src/THcRasteredBeam.cxx
+++ b/src/THcRasteredBeam.cxx
@@ -1,7 +1,7 @@
 /** \class THcRasteredBeam
-    \ingroup Detectors
+    \ingroup Base
 
-  A class to handle the raster processing tasks
+\brief  Apparatus for a rastered beam
 
 \author Buddhini Waidyawansa
 
diff --git a/src/THcRunParameters.cxx b/src/THcRunParameters.cxx
index 6f09dc73ae34425d38a0057d8f11393d16ed15ce..7b1060e19ccf22d4b9ecd4fb4e5f8042452cb0a6 100644
--- a/src/THcRunParameters.cxx
+++ b/src/THcRunParameters.cxx
@@ -1,7 +1,7 @@
 /** \class THcRunParameters
     \ingroup Base
 
-Get the run parameters from the Hall C style parameter database
+\brief Get the run parameters from the parameter database
 so that db_run.dat is not needed in hcana.
 
 \author S. A. Wood 15-June-2017
diff --git a/src/THcScalerEvtHandler.cxx b/src/THcScalerEvtHandler.cxx
index 30df4e3f078367d9c31495249a57bf39d1bd5f5f..49584757c52c7d9999ce6e74aef723c37071036a 100644
--- a/src/THcScalerEvtHandler.cxx
+++ b/src/THcScalerEvtHandler.cxx
@@ -1,7 +1,7 @@
 /** \class THcScalerEvtHandler
     \ingroup Base
 
- Event handler for Hall C scalers
+\brief Event handler for Hall C scalers
 
 
 This class does the following
diff --git a/src/THcScintillatorPlane.cxx b/src/THcScintillatorPlane.cxx
index 883b57dffc8812ae38792f23d75da7d6f768f2ba..7f8f8444e0bf32d4620aa40391ff83400b2d63bb 100644
--- a/src/THcScintillatorPlane.cxx
+++ b/src/THcScintillatorPlane.cxx
@@ -1,8 +1,9 @@
 /** \class THcScintillatorPlane
     \ingroup DetSupport
 
-    This class implements a single plane of scintillators.  The THcHodoscope
-    class instatiates one object per plane.
+\brief A single plane of scintillators.
+
+The THcHodoscope class instatiates one of these objects per plane.
 
 */
 #include "TMath.h"
diff --git a/src/THcShower.cxx b/src/THcShower.cxx
index afc22d5e03eac736707e229916bb5be1fea6be93..31e250e10036c10add0792636ff15fd8ede0e885 100644
--- a/src/THcShower.cxx
+++ b/src/THcShower.cxx
@@ -1,7 +1,7 @@
 /** \class THcShower
     \ingroup Detectors
 
-Shower counter class, describing a generic segmented shower detector.     //
+\brief Generic segmented shower detector.
 
 */
  
diff --git a/src/THcShowerArray.cxx b/src/THcShowerArray.cxx
index fa0bc7119f5fdcda8211d2f81e413c325d040ec8..c2a31dcbbc8252e4403064c860236ecdde2f14de 100644
--- a/src/THcShowerArray.cxx
+++ b/src/THcShowerArray.cxx
@@ -1,7 +1,7 @@
 /** \class THcShowerArray
     \ingroup DetSupport
 
-Fly's eye array of shower blocks
+\brief Fly's eye array of shower blocks
 
 */
diff --git a/src/THcParmList.cxx b/src/THcParmList.cxx
index c471c8da6b360d8f8026207ff1d73b844606264d..5e83e2ab6b2087f87a244e1ea30c79a249a45c2d 100644
--- a/src/THcParmList.cxx
+++ b/src/THcParmList.cxx
@@ -1,8 +1,9 @@
 /** \class THcParmList
     \ingroup Base
 
-A THcParmList object holds an arbitrary list of parameters and
-their values.  Parameters may be integers, real numbers or strings.
+\brief A list parameters and their values
+
+Parameters may be integers, real numbers or strings.
 Integers and floating point numbers can be one dimensional arrays.
 (Strings can not be arrays.)  In addition to values, each parameter
 may have a title/description.  (No titles are saved for string parameters.)
@@ -58,7 +59,7 @@ inline static bool IsComment( const string& s, string::size_type pos )
 void THcParmList::Load( const char* fname, Int_t RunNumber )
 {
   /**
-Load the parameter cache by reading a CTP style parameter file.  Most
+\brief Load the parameter cache by reading a CTP style parameter file.  Most
 parameter files used in the ENGINE should work.
 
 A line in the file of the form
@@ -478,7 +479,7 @@ Int_t THcParmList::LoadParmValues(const DBRequest* list, const char* prefix)
 {
   /**
 
-Retrieve parameter values from the parameter cache.
+\brief Retrieve parameter values from the parameter cache.
 
 The following example loads several parameters held in the `gHcParms`
 parameter cache into scalar variables or arrays.
@@ -588,14 +589,18 @@ zero), then there will be no error if the parameter is missing.
 //_____________________________________________________________________________
 Int_t THcParmList::GetArray(const char* attr, Int_t* array, Int_t size)
 {
-  // Read in a set of Int_t's in to a C-style array.
+  /**
+  \brief  Read in a set of Int_t's in to a C-style array.
+  */
 
   return ReadArray(attr,array,size);
 }
 //_____________________________________________________________________________
 Int_t THcParmList::GetArray(const char* attr, Double_t* array, Int_t size)
 {
-  // Read in a set of Double_t's in to a vector.
+  /**
+  \brief Read in a set of Double_t's in to a vector.
+  */
 
   return ReadArray(attr,array,size);
 }
@@ -604,8 +609,10 @@ Int_t THcParmList::GetArray(const char* attr, Double_t* array, Int_t size)
 template<class T>
 Int_t THcParmList::ReadArray(const char* attrC, T* array, Int_t size)
 {
-  // Copy values from parameter store to array
-  // No resizing is done, so only 'size' elements may be stored.
+  /**
+  \brief Copy values from parameter store to array.
+  No resizing is done, so only 'size' elements may be stored.
+  */
 
   Int_t cnt=0;
 
@@ -644,8 +651,8 @@ Int_t THcParmList::ReadArray(const char* attrC, T* array, Int_t size)
 //_____________________________________________________________________________
 void THcParmList::PrintFull( Option_t* option ) const
 {
   // Print all the numeric parameter desciptions and values.
   // Print all the text parameters
   THaVarList::PrintFull(option);
   TextList->Print();
 }
@@ -763,4 +770,3 @@ Int_t THcParmList::LoadCCDBDirectory(const char* directory,
 }
 
 #endif
-
@@ -644,8 +651,8 @@ Int_t THcParmList::ReadArray(const char* attrC, T* array, Int_t size)
 void THcParmList::PrintFull( Option_t* option ) const
 {
-  // Print all the numeric parameter desciptions and values.
-  // Print all the text parameters
+  /** \brief Print all the numeric parameter desciptions and value and text parameters.
+  */
   THaVarList::PrintFull(option);
   TextList->Print();